@@ -31,6 +31,22 @@ function setCurrentColor(color) {
     di.setCurrentColor(color);
 }
 
+/**
+ * Checks if the given layer exists.
+ * \ingroup ecma_simple
+ *
+ * \code
+ * hasLayer("MyLayer1")
+ * \endcode
+ */
+function hasLayer(name) {
+    var doc = getTransactionDocument();
+    if (isNull(doc)) {
+        return false;
+    }
+    return doc.hasLayer(name);
+}
+
 /**
  * Adds a layer to the drawing.
  * \ingroup ecma_simple
@@ -70,6 +86,20 @@ function addLayer(name, colorName, linetypeName, lineWeight) {
     return addObject(layer);
 }
 
+/**
+ * Sets the current layer to the given layer.
+ * \ingroup ecma_simple
+ *
+ * \param layerName Layer name or ID.
+ */
+function setCurrentLayer(layerName) {
+    var di = getTransactionDocumentInterface();
+    if (isNull(di)) {
+        return false;
+    }
+    di.setCurrentLayer(layerName);
+}
+
 /**
  * Adds a point to the drawing.
  * \ingroup ecma_simple
@@ -117,6 +147,33 @@ function addLine(startPoint, endPoint) {
     return addShape(new RLine(startPoint, endPoint));
 }
 
+/**
+ * Adds an infinite line to the drawing.
+ * The two vectors are the base point and the direction vector
+ * (point relative to base point)
+ * \ingroup ecma_simple
+ *
+ * \code
+ * addXLine(x1,y1, dx,dy)
+ * addXLine([x1,y1], [dx,dy])
+ * addXLine(new RVector(x1,y1), new RVector(dx,dy))
+ * \endcode
+ */
+function addXLine(startPoint, directionVector) {
+    if (arguments.length===4) {
+        return addXLine(new RVector(arguments[0], arguments[1]), new RVector(arguments[2], arguments[3]));
+    }
+
+    if (isArray(startPoint)) {
+        startPoint = new RVector(startPoint);
+    }
+    if (isArray(directionVector)) {
+        directionVector = new RVector(directionVector);
+    }
+
+    return addShape(new RXLine(startPoint, directionVector));
+}
+
 /**
  * Adds an arc to the drawing.
  * \ingroup ecma_simple
@@ -175,15 +232,15 @@ function addCircle(center, radius) {
  * relative: True if this vector's coordinates are relative to the previous coordinates,
  * defaults to false.
  *
- * \param closed True for an implicitely closed polyline. Default is false.
+ * \param closed True for an implicitly closed polyline. Default is false.
  * \param relative True to treat all coordinates as relative.
  * The first coordinate is always absolute. Default is false.
  *
  * \code
  * addPolyline([[x1,y1],[x2,y2],[x3,y3]], false)
  * addPolyline([ [ 100 , 0 ], [ 20 , -10 , 1 ], [ 0 , 40 , 0 , true ], [ -20 , -10 , 1 , true ] ])
- * addPolyline([new RVector(x1,y1)],new RVector(x2,y2),new RVector(x3,y3)], closed, relative)
- * addPolyline([new RVector(x1,y1),bulge1,rel1],[new RVector(x2,y2),bulge2,rel2],[new RVector(x3,y3),bulge3,rel3]], closed, relative)
+ * addPolyline([new RVector(x1,y1),new RVector(x2,y2),new RVector(x3,y3)], closed, relative)
+ * addPolyline([[new RVector(x1,y1),bulge1,rel1],[new RVector(x2,y2),bulge2,rel2],[new RVector(x3,y3),bulge3,rel3]], closed, relative)
  * \endcode
  */
 function addPolyline(points, closed, relative) {
@@ -207,22 +264,36 @@ function addPolyline(points, closed, relative) {
             v0 = points[i];
         }
         // first item in vertex tuple is RVector or x,y pair:
-        else if (isVector(points[i][0])) {
-            v0 = points[i][0];
-            if (!isNull(points[i][1])) {
-                b = points[i][1];
+        else if (isArray(points[i])) {
+            if (isVector(points[i][0])) {
+                v0 = points[i][0];
+                if (!isNull(points[i][1])) {
+                    b = points[i][1];
+                }
+                if (!isNull(points[i][2])) {
+                    rel = points[i][2];
+                }
             }
-            if (!isNull(points[i][2])) {
-                rel = points[i][2];
+            else {
+                v0 = new RVector(points[i][0], points[i][1]);
+                if (!isNull(points[i][2])) {
+                    b = points[i][2];
+                }
+                if (!isNull(points[i][3])) {
+                    rel = points[i][3];
+                }
             }
         }
-        else {
-            v0 = new RVector(points[i][0], points[i][1]);
-            if (!isNull(points[i][2])) {
-                b = points[i][2];
+        // custom objects with .x, .y (, .z, .b) members:
+        else if (isNumber(points[i].x) && isNumber(points[i].y)) {
+            if (isNumber(points[i].z)) {
+                v0 = new RVector(points[i].x, points[i].y, points[i].z);
             }
-            if (!isNull(points[i][3])) {
-                rel = points[i][3];
+            else {
+                v0 = new RVector(points[i].x, points[i].y);
+            }
+            if (isNumber(points[i].b)) {
+                b = points[i].b;
             }
         }
 
@@ -249,7 +320,7 @@ function addPolyline(points, closed, relative) {
  *
  * \code
  * addSpline([[x1,y1],[x2,y2],[x3,y3]], false)
- * addSpline([new RVector(x1,y1)],new RVector(x2,y2),new RVector(x3,y3)], false)
+ * addSpline([new RVector(x1,y1),new RVector(x2,y2),new RVector(x3,y3)], false)
  * \endcode
  */
 function addSpline(points, closed) {
@@ -321,7 +392,7 @@ function addSimpleText(text, position, height, angle, font, vAlign, hAlign, bold
               position,
               position,
               height,
-              100.0,
+              0.0,
               vAlign,
               hAlign,
               RS.LeftToRight,
